@@ -181,10 +181,9 @@ test_that("print comment", {
 
   c2 <- create_comment(text = "this is another comment",
                        author = "Marco Polo")
-
-  exp <- "Author: Marco Polo\nText:\n Marco Polo:\nthis is another comment\n\nStyle:\n\n\n\n\nFont name: Calibri\nFont size: 11\nFont color: #000000\n\n"
   got <- capture_output(print(c2), print = TRUE)
-  expect_equal(exp, got)
+  exp <- "Author: Marco Polo\nText:\n Marco Polo:\nthis is another comment\n\nStyle:\n\n\n\n\nFont name: Aptos Narrow\nFont size: 11\nFont color: #000000\n\n"
+  expect_equal(got, exp)
 
 })
 
@@ -313,7 +312,8 @@ test_that("background images work", {
   c1 <- wb_comment(text = "this is a comment", author = "", visible = TRUE)
   wb$add_comment(dims = "B12", comment = c1, file = tmp)
 
-  wb$add_worksheet()
+  img <- system.file("extdata", "einstein.jpg", package = "openxlsx2")
+  wb$add_worksheet()$add_image(dims = "C5", file = img, width = 6, height = 5)
   wb$add_comment(dims = "B12", comment = c1)
 
   wb$add_worksheet()
@@ -329,10 +329,53 @@ test_that("background images work", {
   wb$add_comment(dims = "G12", comment = c1, file = tmp2)
   wb$add_comment(dims = "G12", sheet = 1, comment = c1, file = tmp2)
 
-  expect_equal(3, length(wb$vml))
-  expect_equal(3, length(wb$vml_rels))
-  expect_equal(2, length(wb$vml_rels[[1]]))
-  expect_true(is.null(wb$vml_rels[[2]]))
-  expect_equal(1, length(wb$vml_rels[[3]]))
+  expect_length(wb$vml, 3)
+  expect_length(wb$vml_rels, 3)
+  expect_length(wb$vml_rels[[1]], 2)
+  expect_null(wb$vml_rels[[2]])
+  expect_length(wb$vml_rels[[3]], 1)
+
+})
+
+test_that("More than two background images work", {
+
+  tmp <- tempfile(fileext = ".png")
+  png(file = tmp, bg = "transparent")
+  plot(1:10)
+  dev.off()
+
+  c1 <- wb_comment(text = "Comm1", author = "", visible = TRUE)
+
+  wb <- wb_workbook()$
+    add_worksheet()$
+    add_comment(dims = "A2", comment = c1, file = tmp)$
+    add_comment(dims = "A3", comment = c1, file = tmp)$
+    add_comment(dims = "A4", comment = c1, file = tmp)$
+    add_worksheet()$
+    add_comment(dims = "A2", comment = c1, file = tmp)
+
+  exp <- list(
+    c(
+      "<Relationship Id=\"rId1\" Type=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships/image\" Target=\"../media/image1.png\"/>",
+      "<Relationship Id=\"rId2\" Type=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships/image\" Target=\"../media/image2.png\"/>",
+      "<Relationship Id=\"rId3\" Type=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships/image\" Target=\"../media/image3.png\"/>"
+    ),
+    "<Relationship Id=\"rId1\" Type=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships/image\" Target=\"../media/image4.png\"/>"
+  )
+  got <- wb$vml_rels
+  expect_equal(exp, got)
+
+})
+
+test_that("background colors work", {
+
+  wb <- wb_workbook()$add_worksheet()
+
+  txt <- fmt_txt("This Part Bold red\n\n", bold = TRUE, size = 12, color = wb_color("red")) +
+    fmt_txt("This part black", size = 9, color = wb_color("black"))
+
+  wb$add_comment(sheet = 1, dims = wb_dims(3, 6), comment = wb_comment(text = txt), color = wb_color("green"))
+
+  expect_true(grepl("fillcolor=\"#00FF00\"", wb$vml[[1]]))
 
 })
